# -*- coding: utf-8 -*-
# Generated by Django 3.2.8 on 2021-10-26 13:45

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="BulkTestModel",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("num", models.IntegerField(default=0)),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
